@@ -57,7 +57,7 @@ class SessionState:
 
     def send_error(self, e: Exception):
         try:
-            self.connection.send_error(self.message_id, Config.error_prefix + str(e).encode('utf-8'))
+            self.connection.send_error(self.message_id, str(e))
         except ConnectionError:
             pass
 
@@ -168,7 +168,8 @@ class ModelServer:
                 inputs = {
                     key: self.pad_and_concat(
                         [sample_inputs[key].to(self.device) for sample_inputs in inputs], pad_map.get(key, 0))
-                    for key in keys}
+                    for key in keys
+                }
                 with torch.no_grad():
                     outputs = self.model.forward(**inputs)
                 for session_state, output in zip(session_states, self.split_output(outputs, sizes)):
